@@ -12,6 +12,7 @@ from lightseq.training.ops.pytorch.util import (
     state_dict,
     MODEL_ARCH,
     check_config,
+    calc_offset,
 )
 
 transformer_cuda_module = None
@@ -129,26 +130,8 @@ class LSTransformerEncoderLayer(nn.Module):
 
         hs = self.config.hidden_size
         ims = self.config.intermediate_size
-        nums = [
-            hs * hs * 3,  # attn_qkvw
-            hs * 3,  # attn_qkvb
-            hs * hs,  # attn_ow
-            hs,  # attn_ob
-            hs,  # attn_nw
-            hs,  # attn_nb
-            hs * ims,  # inter_w
-            ims,  # inter_b
-            hs * ims,  # output_w
-            hs,  # output_b
-            hs,  # ffn_nw
-            hs,  # ffn_nb
-        ]
-        offset = 0
-        self.para_offset = [offset]
-        for n in nums:
-            offset += n
-            self.para_offset.append(offset)
-        self.para = nn.Parameter(torch.Tensor(offset))
+        self.para_offset = LSTransformerEncoderLayer.gen_offset(hs, ims)
+        self.para = nn.Parameter(torch.Tensor(self.para_offset[-1]))
 
         if initial_weights is None and initial_biases is None:
             self.init_transformer_weights()
@@ -202,6 +185,26 @@ class LSTransformerEncoderLayer(nn.Module):
         check_config(config)
         return config
 
+    @staticmethod
+    def gen_offset(hidden_size, intermediate_size):
+        hs, ims = hidden_size, intermediate_size
+        sizes = [
+            hs * hs * 3,  # attn_qkvw
+            hs * 3,  # attn_qkvb
+            hs * hs,  # attn_ow
+            hs,  # attn_ob
+            hs,  # attn_nw
+            hs,  # attn_nb
+            hs * ims,  # inter_w
+            ims,  # inter_b
+            hs * ims,  # output_w
+            hs,  # output_b
+            hs,  # ffn_nw
+            hs,  # ffn_nb
+        ]
+        offsets = calc_offset(sizes)
+        return offsets
+
     def _get_weights(self, i):
         return self.para.data.narrow(
             0, self.para_offset[i], self.para_offset[i + 1] - self.para_offset[i]
@@ -285,7 +288,12 @@ class LSTransformerEncoderLayer(nn.Module):
             raise ValueError(
                 f"Sequence length {sl} exceeds the limit {self.config.max_seq_len}."
             )
-        assert bs == encoder_padding_mask.size(0) and sl == encoder_padding_mask.size(1)
+        if len(encoder_padding_mask.size()) == 1:
+            assert bs == 1 and sl == encoder_padding_mask.size(0)
+        else:
+            assert bs == encoder_padding_mask.size(
+                0
+            ) and sl == encoder_padding_mask.size(1)
         output = LSTransformerEncoderFunc.apply(
             hidden_states,
             encoder_padding_mask,
